# Changelog

## 1.1.0

-   Updated default authentication scopes to \"lfa\".
-   Added environment variable `LSEG_ANALYTICS_PROXY_URL` to support
    custom proxy server configuration.
-   Removed unnecessary libraries in dependencies

### 1.0.0

-   Updated error message for seamless authentication
-   Initial release of the lseg-analytics-core package, provides basic
    configuration and SDKSession for single authentication.
